Class: Bee::Task::Go
- Inherits:
-
Package
- Object
- Package
- Bee::Task::Go
- Defined in:
- lib/bee_task_go.rb
Overview
Package for Go tasks.
Instance Method Summary collapse
-
#hello(who) ⇒ Object
Sample hello task that prints greeting message on console.
Instance Method Details
#hello(who) ⇒ Object
Sample hello task that prints greeting message on console.
-
who: who to greet.
Example
- go.hello: "World"
17 18 19 |
# File 'lib/bee_task_go.rb', line 17 def hello(who) puts "Hello #{who}!" end |